@@ -32,8 +32,6 @@ fn main() {
         .arg(Arg::with_name("operation")
             .help("Sets the operation to run")
             .possible_values(&[
-                "ActivateUser",
-                "DeactivateUser",
                 "QueryUserById",
                 "QueryUsers",
             ])
@@ -79,11 +77,14 @@ fn main() {
     let mut rt = tokio::runtime::Runtime::new().unwrap();
 
     match matches.value_of("operation") {
+        /* Disabled because there's no example.
         Some("ActivateUser") => {
             let result = rt.block_on(client.activate_user(
+                  ???
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
+        */
         /* Disabled because there's no example.
         Some("CreateUser") => {
             let result = rt.block_on(client.create_user(
@@ -92,11 +93,14 @@ fn main() {
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
         */
+        /* Disabled because there's no example.
         Some("DeactivateUser") => {
             let result = rt.block_on(client.deactivate_user(
+                  ???
             ));
             info!("{:?} (X-Span-ID: {:?})", result, (client.context() as &dyn Has<XSpanIdString>).get().clone());
         },
+        */
         /* Disabled because there's no example.
         Some("UpdatePassword") => {
             let result = rt.block_on(client.update_password(
