@@ -387,6 +387,7 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn activate_user(
         &self,
+        param_inline_object2: models::InlineObject2,
         context: &C) -> Result<ActivateUserResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
@@ -418,6 +419,15 @@ impl<S, C> Api<C> for Client<S, C> where
                 Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
         };
 
+        // Body parameter
+        let body = serde_json::to_string(&param_inline_object2).expect("impossible to fail to serialize");
+                *request.body_mut() = Body::from(body);
+
+        let header = "application/json";
+        request.headers_mut().insert(CONTENT_TYPE, match HeaderValue::from_str(header) {
+            Ok(h) => h,
+            Err(e) => return Err(ApiError(format!("Unable to create header: {} - {}", header, e)))
+        });
         let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
         request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
             Ok(h) => h,
@@ -490,7 +500,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/identity-service/user",
+            "{}/mutation-api/identity-service/users",
             self.base_path
         );
 
@@ -592,6 +602,7 @@ impl<S, C> Api<C> for Client<S, C> where
 
     async fn deactivate_user(
         &self,
+        param_inline_object1: models::InlineObject1,
         context: &C) -> Result<DeactivateUserResponse, ApiError>
     {
         let mut client_service = self.client_service.clone();
@@ -623,6 +634,14 @@ impl<S, C> Api<C> for Client<S, C> where
                 Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
         };
 
+        let body = serde_json::to_string(&param_inline_object1).expect("impossible to fail to serialize");
+                *request.body_mut() = Body::from(body);
+
+        let header = "application/json";
+        request.headers_mut().insert(CONTENT_TYPE, match HeaderValue::from_str(header) {
+            Ok(h) => h,
+            Err(e) => return Err(ApiError(format!("Unable to create header: {} - {}", header, e)))
+        });
         let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
         request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
             Ok(h) => h,
