@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.0.2";
+pub const API_VERSION: &'static str = "0.0.4";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -94,6 +94,7 @@ pub trait Api<C: Send + Sync> {
     /// Activate a user
     async fn activate_user(
         &self,
+        inline_object2: models::InlineObject2,
         context: &C) -> Result<ActivateUserResponse, ApiError>;
 
     /// Create user
@@ -105,6 +106,7 @@ pub trait Api<C: Send + Sync> {
     /// Deactive user
     async fn deactivate_user(
         &self,
+        inline_object1: models::InlineObject1,
         context: &C) -> Result<DeactivateUserResponse, ApiError>;
 
     /// update password
@@ -139,6 +141,7 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Activate a user
     async fn activate_user(
         &self,
+        inline_object2: models::InlineObject2,
         ) -> Result<ActivateUserResponse, ApiError>;
 
     /// Create user
@@ -150,6 +153,7 @@ pub trait ApiNoContext<C: Send + Sync> {
     /// Deactive user
     async fn deactivate_user(
         &self,
+        inline_object1: models::InlineObject1,
         ) -> Result<DeactivateUserResponse, ApiError>;
 
     /// update password
@@ -199,10 +203,11 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Activate a user
     async fn activate_user(
         &self,
+        inline_object2: models::InlineObject2,
         ) -> Result<ActivateUserResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().activate_user(&context).await
+        self.api().activate_user(inline_object2, &context).await
     }
 
     /// Create user
@@ -218,10 +223,11 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
     /// Deactive user
     async fn deactivate_user(
         &self,
+        inline_object1: models::InlineObject1,
         ) -> Result<DeactivateUserResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().deactivate_user(&context).await
+        self.api().deactivate_user(inline_object1, &context).await
     }
 
     /// update password
