@@ -35,7 +35,7 @@ mod paths {
 
     lazy_static! {
         pub static ref GLOBAL_REGEX_SET: regex::RegexSet = regex::RegexSet::new(vec![
-            r"^/mutation-api/identity-service/user$",
+            r"^/mutation-api/identity-service/users$",
             r"^/mutation-api/identity-service/users/activation$",
             r"^/mutation-api/identity-service/users/deactivation$",
             r"^/mutation-api/identity-service/users/password$",
@@ -44,7 +44,7 @@ mod paths {
         ])
         .expect("Unable to create global regex set");
     }
-    pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USER: usize = 0;
+    pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS: usize = 0;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION: usize = 1;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION: usize = 2;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD: usize = 3;
@@ -171,7 +171,38 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                     };
                 }
 
+                // Body parameters (note that non-required body parameters will ignore garbage
+                // values, rather than causing a 400 response). Produce warning header and logs for
+                // any unused fields.
+                let result = body.to_raw().await;
+                match result {
+                            Ok(body) => {
+                                let mut unused_elements = Vec::new();
+                                let param_inline_object2: Option<models::InlineObject2> = if !body.is_empty() {
+                                    let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
+                                    match serde_ignored::deserialize(deserializer, |path| {
+                                            warn!("Ignoring unknown field in body: {}", path);
+                                            unused_elements.push(path.to_string());
+                                    }) {
+                                        Ok(param_inline_object2) => param_inline_object2,
+                                        Err(e) => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from(format!("Couldn't parse body parameter InlineObject2 - doesn't match schema: {}", e)))
+                                                        .expect("Unable to create Bad Request response for invalid body parameter InlineObject2 due to schema")),
+                                    }
+                                } else {
+                                    None
+                                };
+                                let param_inline_object2 = match param_inline_object2 {
+                                    Some(param_inline_object2) => param_inline_object2,
+                                    None => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from("Missing required body parameter InlineObject2"))
+                                                        .expect("Unable to create Bad Request response for missing body parameter InlineObject2")),
+                                };
+
                                 let result = api_impl.activate_user(
+                                            param_inline_object2,
                                         &context
                                     ).await;
                                 let mut response = Response::new(Body::empty());
@@ -180,6 +211,13 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                             HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
                                                 .expect("Unable to create X-Span-ID header value"));
 
+                                        if !unused_elements.is_empty() {
+                                            response.headers_mut().insert(
+                                                HeaderName::from_static("warning"),
+                                                HeaderValue::from_str(format!("Ignoring unknown fields in body: {:?}", unused_elements).as_str())
+                                                    .expect("Unable to create Warning header value"));
+                                        }
+
                                         match result {
                                             Ok(rsp) => match rsp {
                                                 ActivateUserResponse::SuccessfulOperation
@@ -207,10 +245,16 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         }
 
                                         Ok(response)
+                            },
+                            Err(e) => Ok(Response::builder()
+                                                .status(StatusCode::BAD_REQUEST)
+                                                .body(Body::from(format!("Couldn't read body parameter InlineObject2: {}", e)))
+                                                .expect("Unable to create Bad Request response due to unable to read body parameter InlineObject2")),
+                        }
             },
 
-            // CreateUser - POST /mutation-api/identity-service/user
-            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USER) => {
+            // CreateUser - POST /mutation-api/identity-service/users
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
                         &Some(ref authorization) => authorization,
@@ -315,7 +359,38 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                     };
                 }
 
+                // Body parameters (note that non-required body parameters will ignore garbage
+                // values, rather than causing a 400 response). Produce warning header and logs for
+                // any unused fields.
+                let result = body.to_raw().await;
+                match result {
+                            Ok(body) => {
+                                let mut unused_elements = Vec::new();
+                                let param_inline_object1: Option<models::InlineObject1> = if !body.is_empty() {
+                                    let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
+                                    match serde_ignored::deserialize(deserializer, |path| {
+                                            warn!("Ignoring unknown field in body: {}", path);
+                                            unused_elements.push(path.to_string());
+                                    }) {
+                                        Ok(param_inline_object1) => param_inline_object1,
+                                        Err(e) => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from(format!("Couldn't parse body parameter InlineObject1 - doesn't match schema: {}", e)))
+                                                        .expect("Unable to create Bad Request response for invalid body parameter InlineObject1 due to schema")),
+                                    }
+                                } else {
+                                    None
+                                };
+                                let param_inline_object1 = match param_inline_object1 {
+                                    Some(param_inline_object1) => param_inline_object1,
+                                    None => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from("Missing required body parameter InlineObject1"))
+                                                        .expect("Unable to create Bad Request response for missing body parameter InlineObject1")),
+                                };
+
                                 let result = api_impl.deactivate_user(
+                                            param_inline_object1,
                                         &context
                                     ).await;
                                 let mut response = Response::new(Body::empty());
@@ -324,6 +399,13 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                             HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
                                                 .expect("Unable to create X-Span-ID header value"));
 
+                                        if !unused_elements.is_empty() {
+                                            response.headers_mut().insert(
+                                                HeaderName::from_static("warning"),
+                                                HeaderValue::from_str(format!("Ignoring unknown fields in body: {:?}", unused_elements).as_str())
+                                                    .expect("Unable to create Warning header value"));
+                                        }
+
                                         match result {
                                             Ok(rsp) => match rsp {
                                                 DeactivateUserResponse::SuccessfulOperation
@@ -351,6 +433,12 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         }
 
                                         Ok(response)
+                            },
+                            Err(e) => Ok(Response::builder()
+                                                .status(StatusCode::BAD_REQUEST)
+                                                .body(Body::from(format!("Couldn't read body parameter InlineObject1: {}", e)))
+                                                .expect("Unable to create Bad Request response due to unable to read body parameter InlineObject1")),
+                        }
             },
 
             // UpdatePassword - PUT /mutation-api/identity-service/users/password
@@ -618,7 +706,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
-            _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USER) => method_not_allowed(),
+            _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD) => method_not_allowed(),
@@ -639,8 +727,8 @@ impl<T> RequestParser<T> for ApiRequestParser {
         match request.method() {
             // ActivateUser - POST /mutation-api/identity-service/users/activation
             &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION) => Ok("ActivateUser"),
-            // CreateUser - POST /mutation-api/identity-service/user
-            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USER) => Ok("CreateUser"),
+            // CreateUser - POST /mutation-api/identity-service/users
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => Ok("CreateUser"),
             // DeactivateUser - POST /mutation-api/identity-service/users/deactivation
             &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => Ok("DeactivateUser"),
             // UpdatePassword - PUT /mutation-api/identity-service/users/password
